@@ -14,5 +14,5 @@ test -n "$SSH_ASKPASS" || {
 		;;
 	esac
 }
-export PATH=$(cygpath -a C:/bld/git_1513253749186/_b_env)/Library/bin:$PATH 
+export PATH=$(cygpath -a C:/bld/git_1541270574175/_h_env)/Library/bin:$PATH 
  
