@@ -1,21 +1,5 @@
 #!/bin/bash
 
-export C_INCLUDE_PATH="${PREFIX}/include"
-export LIBRARY_PATH="${PREFIX}/lib"
-
-if [ "$(uname)" == "Darwin" ]
-then
-    export LDFLAGS="-Wl,-rpath,$PREFIX/lib"
-elif [ "$(uname)" == "Linux" ]
-then
-    export LDFLAGS="-Wl,-rpath=$PREFIX/lib"
-fi
-
-# NO_TCLTK disables git-gui
-# NO_PERL disables all perl-based utils:
-#   git-instaweb, gitweb, git-cvsserver, git-svn
-#   /ref http://www.spinics.net/lists/git/msg99803.html
-# NO_GETTEXT disables internationalization (localized message translations)
 # NO_INSTALL_HARDLINKS uses symlinks which makes the package 85MB slimmer (8MB instead of 93MB!)
 
 # Add a place for git config files.
@@ -25,12 +9,11 @@ make configure
     --prefix="${PREFIX}" \
     --with-gitattributes="${PREFIX}/etc/gitattributes" \
     --with-gitconfig="${PREFIX}/etc/gitconfig" \
-    --with-iconv="${PREFIX}/lib"
+    --with-iconv="${PREFIX}/lib" \
+    --with-perl="${PREFIX}/bin/perl" \
+    --with-tcltk="${PREFIX}/bin/tclsh"
 make \
     --jobs="$CPU_COUNT" \
-    NO_TCLTK=1 \
-    NO_PERL=1 \
-    NO_GETTEXT=1 \
     NO_INSTALL_HARDLINKS=1 \
     all strip install
 
